@@ -2,7 +2,7 @@
 import logging
 from typing import List, Dict
 
-import botostubs
+from mypy_boto3_config.client import ConfigServiceClient
 
 from amplify_aws_utils.resource_helper import throttled_call, chunker
 
@@ -13,10 +13,12 @@ logger = logging.getLogger(__name__)
 class Config:
     """Class for wrapping common Config API calls"""
 
-    def __init__(self, config_client: botostubs.ConfigService):
+    def __init__(self, config_client: ConfigServiceClient):
         self.config_client = config_client
 
-    def put_evaluations(self, result_token: str, evaluations: List[Dict[str, str]]) -> None:
+    def put_evaluations(
+        self, result_token: str, evaluations: List[Dict[str, str]]
+    ) -> None:
         """
         Convenience function for submitting evaluations to the AWS Config service in chunks of 100.
         :param result_token: The result token that yielded these evaluations.
@@ -26,15 +28,12 @@ class Config:
             logger.info(
                 "Submitting evaluations for: %s",
                 [
-                    (
-                        evaluation["ComplianceResourceId"],
-                        evaluation["ComplianceType"]
-                    )
+                    (evaluation["ComplianceResourceId"], evaluation["ComplianceType"])
                     for evaluation in evaluation_group
-                ]
+                ],
             )
             throttled_call(
                 self.config_client.put_evaluations,
                 ResultToken=result_token,
-                Evaluations=evaluation_group
+                Evaluations=evaluation_group,
             )
